from setuptools import setup, find_packages
import codecs
import os

# If we get stuck, check out this tutorial: https://www.youtube.com/watch?v=tEFkHEKypLI

### To upload to PyPi ###
# pip install setuptools --upgrade
# pip install wheel --upgrade
# pip install twine --upgrade
# python setup.py sdist bdist_wheel
# twine upload dist/*
### Use your PyPi credentials when prompted ###

here = os.path.abspath(os.path.dirname(__file__))

with open("README.md", "r") as fh:
    long_description = fh.read()

PACKAGE_NAME = "BubbleNova"
VERSION = '0.0.4'
AUTHOR = "SoapDoesCode"
AUTHOR_EMAIL = ""
DESCRIPTION = "A Python library for running multiple Discord bots at once."

# Setting up
setup(
    name=PACKAGE_NAME,
    version=VERSION,
    author=AUTHOR,
    author_email=AUTHOR_EMAIL,
    description=DESCRIPTION,
    long_description=long_description,
    long_description_content_type="text/markdown",
    packages=find_packages(),
    install_requires=[], # required packages
    keywords=['python', 'discord', 'disord bot', 'bubble nova'],
    classifiers=[
        "Development Status :: 1 - Planning", # https://pypi.org/classifiers/
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ]
)


import subprocess
import threading
import os
import sys

def __start_threads(bot_dir):
    subprocess.call([sys.executable, '-u', bot_dir])

def start_bots(bot_list: dict):
    threads = []
    for bot in bot_list:
        bot_dir = bot_list[bot]
        thread = threading.Thread(target=__start_threads, args=(bot_dir,))
        thread.start()
        threads.append(thread)



# if __name__ == "__main__":
#     bot_list = {
#         "SoapBot": "bots/SoapBot.py",
#         "Bubbles": "bots/Bubbles.py"
#     }
#     start_bots(bot_list)
#     print("This code here can still run even though the bots are also still online!")